@@ -1,4 +1,4 @@
-#!/usr/bin/perl -w
+#!/usr/bin/env perl
 # 
 # Copyright (C) 2004 Naba Kumar  <naba@gnome.org>
 # 
@@ -17,6 +17,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 use strict;
+use warnings;
 use Data::Dumper;
 
 if (@ARGV != 1)
@@ -142,6 +143,11 @@ my $type_map = {
 		"gtype" => "G_TYPE_OBJECT",
 		"type" => "IANJUTA_TYPE_ITERABLE",
 		"fail_return" => "NULL"
+	},
+	"IAnjutaDocument*" => {
+		"gtype" => "G_TYPE_OBJECT",
+		"type" => "IANJUTA_TYPE_DOCUMENT",
+		"fail_return" => "NULL"
 	}
 };
 
