@@ -1,7 +1,5 @@
 #include "libanjuta-iface-marshallers.h"
-
-#include	<glib-object.h>
-
+#include <glib-object.h>
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
@@ -49,22 +47,21 @@
 #define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
-
 /* BOOLEAN:OBJECT (./libanjuta-iface-marshallers.list:1) */
 void
 libanjuta_iface_cclosure_marshal_BOOLEAN__OBJECT (GClosure     *closure,
-                                                  GValue       *return_value G_GNUC_UNUSED,
+                                                  GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint G_GNUC_UNUSED,
                                                   gpointer      marshal_data)
 {
-  typedef gboolean (*GMarshalFunc_BOOLEAN__OBJECT) (gpointer     data1,
-                                                    gpointer     arg_1,
-                                                    gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef gboolean (*GMarshalFunc_BOOLEAN__OBJECT) (gpointer data1,
+                                                    gpointer arg1,
+                                                    gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT callback;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -98,13 +95,13 @@ libanjuta_iface_cclosure_marshal_VOID__BOOLEAN_INT (GClosure     *closure,
                                                     gpointer      invocation_hint G_GNUC_UNUSED,
                                                     gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__BOOLEAN_INT) (gpointer     data1,
-                                                  gboolean     arg_1,
-                                                  gint         arg_2,
-                                                  gpointer     data2);
-  register GMarshalFunc_VOID__BOOLEAN_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__BOOLEAN_INT) (gpointer data1,
+                                                  gboolean arg1,
+                                                  gint arg2,
+                                                  gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__BOOLEAN_INT callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -127,10 +124,109 @@ libanjuta_iface_cclosure_marshal_VOID__BOOLEAN_INT (GClosure     *closure,
 }
 
 /* VOID:BOXED (./libanjuta-iface-marshallers.list:3) */
+void
+libanjuta_iface_cclosure_marshal_VOID__BOXED (GClosure     *closure,
+                                              GValue       *return_value G_GNUC_UNUSED,
+                                              guint         n_param_values,
+                                              const GValue *param_values,
+                                              gpointer      invocation_hint G_GNUC_UNUSED,
+                                              gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__BOXED) (gpointer data1,
+                                            gpointer arg1,
+                                            gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__BOXED callback;
+
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__BOXED) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_boxed (param_values + 1),
+            data2);
+}
 
 /* VOID:ENUM (./libanjuta-iface-marshallers.list:4) */
+void
+libanjuta_iface_cclosure_marshal_VOID__ENUM (GClosure     *closure,
+                                             GValue       *return_value G_GNUC_UNUSED,
+                                             guint         n_param_values,
+                                             const GValue *param_values,
+                                             gpointer      invocation_hint G_GNUC_UNUSED,
+                                             gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__ENUM) (gpointer data1,
+                                           gint arg1,
+                                           gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__ENUM callback;
+
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__ENUM) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_enum (param_values + 1),
+            data2);
+}
 
 /* VOID:INT (./libanjuta-iface-marshallers.list:5) */
+void
+libanjuta_iface_cclosure_marshal_VOID__INT (GClosure     *closure,
+                                            GValue       *return_value G_GNUC_UNUSED,
+                                            guint         n_param_values,
+                                            const GValue *param_values,
+                                            gpointer      invocation_hint G_GNUC_UNUSED,
+                                            gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__INT) (gpointer data1,
+                                          gint arg1,
+                                          gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__INT callback;
+
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__INT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_int (param_values + 1),
+            data2);
+}
 
 /* VOID:INT,INT (./libanjuta-iface-marshallers.list:6) */
 void
@@ -141,13 +237,13 @@ libanjuta_iface_cclosure_marshal_VOID__INT_INT (GClosure     *closure,
                                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                                 gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer     data1,
-                                              gint         arg_1,
-                                              gint         arg_2,
-                                              gpointer     data2);
-  register GMarshalFunc_VOID__INT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer data1,
+                                              gint arg1,
+                                              gint arg2,
+                                              gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__INT_INT callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -178,16 +274,16 @@ libanjuta_iface_cclosure_marshal_VOID__INT_INT_ULONG_STRING_UINT (GClosure     *
                                                                   gpointer      invocation_hint G_GNUC_UNUSED,
                                                                   gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__INT_INT_ULONG_STRING_UINT) (gpointer     data1,
-                                                                gint         arg_1,
-                                                                gint         arg_2,
-                                                                gulong       arg_3,
-                                                                gpointer     arg_4,
-                                                                guint        arg_5,
-                                                                gpointer     data2);
-  register GMarshalFunc_VOID__INT_INT_ULONG_STRING_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__INT_INT_ULONG_STRING_UINT) (gpointer data1,
+                                                                gint arg1,
+                                                                gint arg2,
+                                                                gulong arg3,
+                                                                gpointer arg4,
+                                                                guint arg5,
+                                                                gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__INT_INT_ULONG_STRING_UINT callback;
 
   g_return_if_fail (n_param_values == 6);
 
@@ -213,6 +309,39 @@ libanjuta_iface_cclosure_marshal_VOID__INT_INT_ULONG_STRING_UINT (GClosure     *
 }
 
 /* VOID:OBJECT (./libanjuta-iface-marshallers.list:8) */
+void
+libanjuta_iface_cclosure_marshal_VOID__OBJECT (GClosure     *closure,
+                                               GValue       *return_value G_GNUC_UNUSED,
+                                               guint         n_param_values,
+                                               const GValue *param_values,
+                                               gpointer      invocation_hint G_GNUC_UNUSED,
+                                               gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__OBJECT) (gpointer data1,
+                                             gpointer arg1,
+                                             gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT callback;
+
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__OBJECT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_object (param_values + 1),
+            data2);
+}
 
 /* VOID:OBJECT,BOOLEAN,INT,INT,STRING (./libanjuta-iface-marshallers.list:9) */
 void
@@ -223,16 +352,16 @@ libanjuta_iface_cclosure_marshal_VOID__OBJECT_BOOLEAN_INT_INT_STRING (GClosure
                                                                       gpointer      invocation_hint G_GNUC_UNUSED,
                                                                       gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__OBJECT_BOOLEAN_INT_INT_STRING) (gpointer     data1,
-                                                                    gpointer     arg_1,
-                                                                    gboolean     arg_2,
-                                                                    gint         arg_3,
-                                                                    gint         arg_4,
-                                                                    gpointer     arg_5,
-                                                                    gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_BOOLEAN_INT_INT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__OBJECT_BOOLEAN_INT_INT_STRING) (gpointer data1,
+                                                                    gpointer arg1,
+                                                                    gboolean arg2,
+                                                                    gint arg3,
+                                                                    gint arg4,
+                                                                    gpointer arg5,
+                                                                    gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_BOOLEAN_INT_INT_STRING callback;
 
   g_return_if_fail (n_param_values == 6);
 
@@ -266,13 +395,13 @@ libanjuta_iface_cclosure_marshal_VOID__OBJECT_CHAR (GClosure     *closure,
                                                     gpointer      invocation_hint G_GNUC_UNUSED,
                                                     gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__OBJECT_CHAR) (gpointer     data1,
-                                                  gpointer     arg_1,
-                                                  gchar        arg_2,
-                                                  gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_CHAR callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__OBJECT_CHAR) (gpointer data1,
+                                                  gpointer arg1,
+                                                  gchar arg2,
+                                                  gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_CHAR callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -303,13 +432,13 @@ libanjuta_iface_cclosure_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                                       gpointer      invocation_hint G_GNUC_UNUSED,
                                                       gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__OBJECT_STRING) (gpointer     data1,
-                                                    gpointer     arg_1,
-                                                    gpointer     arg_2,
-                                                    gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__OBJECT_STRING) (gpointer data1,
+                                                    gpointer arg1,
+                                                    gpointer arg2,
+                                                    gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_STRING callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -332,6 +461,39 @@ libanjuta_iface_cclosure_marshal_VOID__OBJECT_STRING (GClosure     *closure,
 }
 
 /* VOID:POINTER (./libanjuta-iface-marshallers.list:12) */
+void
+libanjuta_iface_cclosure_marshal_VOID__POINTER (GClosure     *closure,
+                                                GValue       *return_value G_GNUC_UNUSED,
+                                                guint         n_param_values,
+                                                const GValue *param_values,
+                                                gpointer      invocation_hint G_GNUC_UNUSED,
+                                                gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__POINTER) (gpointer data1,
+                                              gpointer arg1,
+                                              gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__POINTER callback;
+
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__POINTER) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_pointer (param_values + 1),
+            data2);
+}
 
 /* VOID:POINTER,BOXED (./libanjuta-iface-marshallers.list:13) */
 void
@@ -342,13 +504,13 @@ libanjuta_iface_cclosure_marshal_VOID__POINTER_BOXED (GClosure     *closure,
                                                       gpointer      invocation_hint G_GNUC_UNUSED,
                                                       gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__POINTER_BOXED) (gpointer     data1,
-                                                    gpointer     arg_1,
-                                                    gpointer     arg_2,
-                                                    gpointer     data2);
-  register GMarshalFunc_VOID__POINTER_BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__POINTER_BOXED) (gpointer data1,
+                                                    gpointer arg1,
+                                                    gpointer arg2,
+                                                    gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__POINTER_BOXED callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -371,6 +533,39 @@ libanjuta_iface_cclosure_marshal_VOID__POINTER_BOXED (GClosure     *closure,
 }
 
 /* VOID:STRING (./libanjuta-iface-marshallers.list:14) */
+void
+libanjuta_iface_cclosure_marshal_VOID__STRING (GClosure     *closure,
+                                               GValue       *return_value G_GNUC_UNUSED,
+                                               guint         n_param_values,
+                                               const GValue *param_values,
+                                               gpointer      invocation_hint G_GNUC_UNUSED,
+                                               gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__STRING) (gpointer data1,
+                                             gpointer arg1,
+                                             gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__STRING callback;
+
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__STRING) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_string (param_values + 1),
+            data2);
+}
 
 /* VOID:STRING,STRING (./libanjuta-iface-marshallers.list:15) */
 void
@@ -381,13 +576,13 @@ libanjuta_iface_cclosure_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                       gpointer      invocation_hint G_GNUC_UNUSED,
                                                       gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__STRING_STRING) (gpointer     data1,
-                                                    gpointer     arg_1,
-                                                    gpointer     arg_2,
-                                                    gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__STRING_STRING) (gpointer data1,
+                                                    gpointer arg1,
+                                                    gpointer arg2,
+                                                    gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -418,14 +613,14 @@ libanjuta_iface_cclosure_marshal_VOID__STRING_STRING_STRING (GClosure     *closu
                                                              gpointer      invocation_hint G_GNUC_UNUSED,
                                                              gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING) (gpointer     data1,
-                                                           gpointer     arg_1,
-                                                           gpointer     arg_2,
-                                                           gpointer     arg_3,
-                                                           gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING) (gpointer data1,
+                                                           gpointer arg1,
+                                                           gpointer arg2,
+                                                           gpointer arg3,
+                                                           gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING_STRING callback;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -457,18 +652,18 @@ libanjuta_iface_cclosure_marshal_VOID__STRING_STRING_STRING_STRING_BOOLEAN_BOOLE
                                                                                            gpointer      invocation_hint G_GNUC_UNUSED,
                                                                                            gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING_STRING_BOOLEAN_BOOLEAN_STRING) (gpointer     data1,
-                                                                                         gpointer     arg_1,
-                                                                                         gpointer     arg_2,
-                                                                                         gpointer     arg_3,
-                                                                                         gpointer     arg_4,
-                                                                                         gboolean     arg_5,
-                                                                                         gboolean     arg_6,
-                                                                                         gpointer     arg_7,
-                                                                                         gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING_STRING_STRING_BOOLEAN_BOOLEAN_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING_STRING_BOOLEAN_BOOLEAN_STRING) (gpointer data1,
+                                                                                         gpointer arg1,
+                                                                                         gpointer arg2,
+                                                                                         gpointer arg3,
+                                                                                         gpointer arg4,
+                                                                                         gboolean arg5,
+                                                                                         gboolean arg6,
+                                                                                         gpointer arg7,
+                                                                                         gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING_STRING_STRING_BOOLEAN_BOOLEAN_STRING callback;
 
   g_return_if_fail (n_param_values == 8);
 
@@ -504,13 +699,13 @@ libanjuta_iface_cclosure_marshal_VOID__UINT_INT (GClosure     *closure,
                                                  gpointer      invocation_hint G_GNUC_UNUSED,
                                                  gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__UINT_INT) (gpointer     data1,
-                                               guint        arg_1,
-                                               gint         arg_2,
-                                               gpointer     data2);
-  register GMarshalFunc_VOID__UINT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__UINT_INT) (gpointer data1,
+                                               guint arg1,
+                                               gint arg2,
+                                               gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_INT callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -541,14 +736,14 @@ libanjuta_iface_cclosure_marshal_VOID__ULONG_STRING_UINT (GClosure     *closure,
                                                           gpointer      invocation_hint G_GNUC_UNUSED,
                                                           gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__ULONG_STRING_UINT) (gpointer     data1,
-                                                        gulong       arg_1,
-                                                        gpointer     arg_2,
-                                                        guint        arg_3,
-                                                        gpointer     data2);
-  register GMarshalFunc_VOID__ULONG_STRING_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__ULONG_STRING_UINT) (gpointer data1,
+                                                        gulong arg1,
+                                                        gpointer arg2,
+                                                        guint arg3,
+                                                        gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__ULONG_STRING_UINT callback;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -572,4 +767,35 @@ libanjuta_iface_cclosure_marshal_VOID__ULONG_STRING_UINT (GClosure     *closure,
 }
 
 /* VOID:VOID (./libanjuta-iface-marshallers.list:20) */
+void
+libanjuta_iface_cclosure_marshal_VOID__VOID (GClosure     *closure,
+                                             GValue       *return_value G_GNUC_UNUSED,
+                                             guint         n_param_values,
+                                             const GValue *param_values,
+                                             gpointer      invocation_hint G_GNUC_UNUSED,
+                                             gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__VOID) (gpointer data1,
+                                           gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__VOID callback;
+
+  g_return_if_fail (n_param_values == 1);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__VOID) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            data2);
+}
 
