@@ -36,13 +36,12 @@
 #define CONFIGURE_DIALOG "configure_dialog"
 #define RUN_AUTOGEN_CHECK "force_autogen_check"
 #define CONFIGURATION_COMBO "configuration_combo_entry"
-#define BUILD_DIR_CHOOSER "build_dir_chooser"
+#define BUILD_DIR_BUTTON "build_dir_button"
+#define BUILD_DIR_LABEL "build_dir_label"
 #define CONFIGURE_ARGS_ENTRY "configure_args_entry"
 #define ENVIRONMENT_EDITOR "environment_editor"
 #define OK_BUTTON "ok_button"
 
-#define GTK_FILE_CHOOSER_CREATE_DIRECTORY_QUARK (build_gtk_file_chooser_create_directory_get_quark ())
-
 
 /* Type defintions
  *---------------------------------------------------------------------------*/
@@ -55,184 +54,70 @@ struct _BuildConfigureDialog
 
 	GtkWidget *combo;
 	GtkWidget *autogen;
-	GtkWidget *build_dir_chooser;
+	GtkWidget *build_dir_button;
+	GtkWidget *build_dir_label;
 	GtkWidget *args;
 	GtkWidget *env_editor;
 	GtkWidget *ok;
 
+	
 	BuildConfigurationList *config_list;
 
 	const gchar *project_uri;
+	GFile *build_file;
 };
 
-typedef struct _BuildMissingDirectory BuildMissingDirectory;
-
-struct _BuildMissingDirectory
-{
-	gsize exist;
-	gchar uri[1];
-};
-
-
 /* Create directory at run time for GtkFileChooserButton
  *---------------------------------------------------------------------------*/
 
-/* Create a directories, including parents if necessary, return
- * */
-
-static GFile*
-build_make_directories (GFile *file,
-							   GCancellable *cancellable,
-							   GError **error)
-{
-	GError *path_error = NULL;
-	GList *children = NULL;
-	GFile *parent;
-
-	parent = g_file_get_parent(file);
-
-	for (;;)
-	{
-		if (g_file_make_directory (file, NULL, &path_error))
-		{
-			/* Making child directory succeed */
-			if (children == NULL)
-			{
-				/* All directories have been created */
-				return parent;
-			}
-			else
-			{
-				/* Get next child directory */
-				g_object_unref (file);
-				file = (GFile *)children->data;
-				children = g_list_delete_link (children, children);
-			}
-		}
-		else if (path_error->code == G_IO_ERROR_NOT_FOUND)
-		{
-			g_clear_error (&path_error);
-			children = g_list_prepend (children, file);
-			file = parent;
-			parent = g_file_get_parent(file);
-		}
-		else
-		{
-			g_object_unref (parent);
-			g_propagate_error (error, path_error);
-
-			return NULL;
-		}
-	}
-}
-
-static GQuark
-build_gtk_file_chooser_create_directory_get_quark (void)
-{
-  static GQuark quark = 0;
-
-  if (quark == 0)
-    quark = g_quark_from_static_string ("gtk-file-chooser-create-directory");
-
-  return quark;
-}
-
-/* Remove created directory */
 static void
-on_build_missing_directory_destroyed (BuildMissingDirectory* dir)
+on_build_dir_button_clicked (GtkButton *button, gpointer user_data)
 {
-	/* Remove previously created directories */
-	GFile* created_dir;
-	GFile* existing_dir;
+	BuildConfigureDialog *dlg = (BuildConfigureDialog *)user_data;
+	GtkWidget *chooser;
+	GFile *file = NULL;
 
-	created_dir = g_file_new_for_uri (dir->uri);
-	dir->uri[dir->exist] = '\0';
-	existing_dir = g_file_new_for_uri (dir->uri);
+	chooser = gtk_file_chooser_dialog_new (_("Select a build directory inside the project directory"),
+	                                       GTK_WINDOW (dlg->win),
+	                                       GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+	                                       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+	                                       GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+	                                       NULL);
 
-	for (;!g_file_equal (created_dir, existing_dir);)
+	if (dlg->build_file != NULL)
 	{
-		GFile *parent_dir;
-
-		if (!g_file_delete (created_dir, NULL, NULL)) break;
-		parent_dir = g_file_get_parent (created_dir);
-		g_object_unref (created_dir);
-		created_dir = parent_dir;
-	}
-	g_object_unref (created_dir);
-	g_object_unref (existing_dir);
-	g_free (dir);
-}
-
-/* If the folder is missing created it before setting it */
-
-static gboolean
-build_gtk_file_chooser_create_and_set_uri (GtkFileChooser *chooser, const gchar *uri)
-{
-	GFile *dir;
-	GError *error = NULL;
-	GFile *parent;
-
-	dir = g_file_new_for_uri (uri);
-	parent = build_make_directories (dir, NULL, &error);
-	if (parent != NULL)
-	{
-		BuildMissingDirectory* dir;
-		gchar *last;
-		gsize len;
-
-		len = strlen (uri);
-		dir = (BuildMissingDirectory *)g_new (char, sizeof (BuildMissingDirectory) + len);
-
-		memcpy (dir->uri, uri, len + 1);
-		last = g_file_get_uri (parent);
-		dir->exist = strlen (last);
-
-		g_object_set_qdata_full (G_OBJECT (chooser),
-								 GTK_FILE_CHOOSER_CREATE_DIRECTORY_QUARK,
-								 dir,
-								 (GDestroyNotify)on_build_missing_directory_destroyed);
+		if (g_file_make_directory_with_parents (dlg->build_file, NULL, NULL)) file = g_object_ref (dlg->build_file);
+		gtk_file_chooser_set_file (GTK_FILE_CHOOSER (chooser), dlg->build_file, NULL);
 	}
 	else
 	{
-		g_object_set_qdata (G_OBJECT (chooser),
-							GTK_FILE_CHOOSER_CREATE_DIRECTORY_QUARK,
-							NULL);
-		g_error_free (error);
+		gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (chooser), dlg->project_uri);
 	}
-	g_object_unref (dir);
 
-	return gtk_file_chooser_set_current_folder_uri (chooser, uri);
-}
-
-/* Do not delete the automatically created folder */
-static void
-build_gtk_file_chooser_keep_folder (GtkFileChooser *chooser, const char *uri)
-{
-	BuildMissingDirectory* dir;
-
-	dir = g_object_steal_qdata (G_OBJECT (chooser), GTK_FILE_CHOOSER_CREATE_DIRECTORY_QUARK);
-	if (dir != NULL)
+	if (gtk_dialog_run (GTK_DIALOG (chooser)) == GTK_RESPONSE_ACCEPT)
 	{
-		GFile *created_dir;
-		GFile *needed_dir;
+		gchar *basename;
 
-		needed_dir = g_file_new_for_uri (uri);
-		created_dir = g_file_new_for_uri (dir->uri);
-		if (!g_file_equal (created_dir, needed_dir))
-		{
-			/* Need to delete created directory */
-			on_build_missing_directory_destroyed (dir);
-		}
-		else
-		{
-			g_free (dir);
-		}
-		g_object_unref (created_dir);
-		g_object_unref (needed_dir);
+		if (dlg->build_file) g_object_unref (dlg->build_file);
+		dlg->build_file = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (chooser));
+		
+		basename = g_file_get_basename (dlg->build_file);
+		gtk_label_set_text (GTK_LABEL (dlg->build_dir_label), basename);
+		g_free (basename);
 	}
+	if (file != NULL)
+	{
+		while ((file != NULL) && g_file_delete (file, NULL, NULL))
+		{
+			GFile *child = file;
+			file = g_file_get_parent (child);
+			g_object_unref (child);
+		}
+		g_object_unref (file);
+	}
+	gtk_widget_destroy (chooser);
 }
 
-
 /* Helper functions
  *---------------------------------------------------------------------------*/
 
@@ -261,23 +146,25 @@ on_select_configuration (GtkComboBox *widget, gpointer user_data)
 	else
 	{
 		BuildConfiguration *cfg;
-		gchar *uri;
 
 		gtk_widget_set_sensitive (dlg->ok, TRUE);
 
-		cfg = build_configuration_list_select (dlg->config_list, name);
+		cfg = build_configuration_list_get (dlg->config_list, name);
 
 		if (cfg != NULL)
 		{
 			const gchar *args;
 			GList *item;
+			gchar *basename;
 
 			args = build_configuration_get_args (cfg);
 			gtk_entry_set_text (GTK_ENTRY (dlg->args), args == NULL ? "" : args);
 
-			uri = build_configuration_list_get_build_uri (dlg->config_list, cfg);
-			build_gtk_file_chooser_create_and_set_uri (GTK_FILE_CHOOSER (dlg->build_dir_chooser), uri);
-			g_free (uri);
+			if (dlg->build_file != NULL) g_object_unref (dlg->build_file);
+			dlg->build_file = build_configuration_list_get_build_file (dlg->config_list, cfg);
+			basename = g_file_get_basename (dlg->build_file);
+			gtk_label_set_text (GTK_LABEL (dlg->build_dir_label), basename);
+			g_free (basename);
 
 			anjuta_environment_editor_reset (ANJUTA_ENVIRONMENT_EDITOR (dlg->env_editor));
 			for (item = build_configuration_get_variables (cfg); item != NULL; item = g_list_next (item))
@@ -328,7 +215,8 @@ build_dialog_configure (GtkWindow* parent, const gchar *project_root_uri, BuildC
 	    CONFIGURE_DIALOG, &dlg.win,
 	    CONFIGURATION_COMBO, &dlg.combo,
 	    RUN_AUTOGEN_CHECK, &dlg.autogen,
-	    BUILD_DIR_CHOOSER, &dlg.build_dir_chooser,
+	    BUILD_DIR_BUTTON, &dlg.build_dir_button,
+	    BUILD_DIR_LABEL, &dlg.build_dir_label,
 	    CONFIGURE_ARGS_ENTRY, &dlg.args,
 	    ENVIRONMENT_EDITOR, &dlg.env_editor,
 	    OK_BUTTON, &dlg.ok,
@@ -337,11 +225,13 @@ build_dialog_configure (GtkWindow* parent, const gchar *project_root_uri, BuildC
 
 	dlg.config_list = config_list;
 	dlg.project_uri = project_root_uri;
+	dlg.build_file = NULL;
 
 	/* Set run autogen option */
 	if (*run_autogen) gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg.autogen), TRUE);
 
 	g_signal_connect (dlg.combo, "changed", G_CALLBACK (on_select_configuration), &dlg);
+	g_signal_connect (dlg.build_dir_button, "clicked", G_CALLBACK (on_build_dir_button_clicked), &dlg);
 
 	fill_dialog(&dlg);
 
@@ -350,7 +240,6 @@ build_dialog_configure (GtkWindow* parent, const gchar *project_root_uri, BuildC
 	if (response == GTK_RESPONSE_OK)
 	{
 		gchar *name;
-		gchar *uri;
 		const gchar *args;
 		GtkTreeIter iter;
 		gchar **mod_var;
@@ -372,10 +261,12 @@ build_dialog_configure (GtkWindow* parent, const gchar *project_root_uri, BuildC
 		args = gtk_entry_get_text (GTK_ENTRY (dlg.args));
 		build_configuration_set_args (cfg, args);
 
-		uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (dlg.build_dir_chooser));
-		build_configuration_list_set_build_uri (dlg.config_list, cfg, uri);
-		build_gtk_file_chooser_keep_folder (GTK_FILE_CHOOSER (dlg.build_dir_chooser), uri);
-		g_free (uri);
+		if (dlg.build_file != NULL)
+		{
+			gchar *uri = g_file_get_uri (dlg.build_file);
+			build_configuration_list_set_build_uri (dlg.config_list, cfg, uri);
+			g_free (uri);
+		}
 
 		build_configuration_clear_variables (cfg);
 		mod_var = anjuta_environment_editor_get_modified_variables (ANJUTA_ENVIRONMENT_EDITOR (dlg.env_editor));
@@ -393,8 +284,9 @@ build_dialog_configure (GtkWindow* parent, const gchar *project_root_uri, BuildC
 		}
 		g_strfreev (mod_var);
 	}
+	if (dlg.build_file != NULL) g_object_unref (dlg.build_file);
 	gtk_widget_destroy (GTK_WIDGET(dlg.win));
-
+	
 	return cfg != NULL;
 }
 
