@@ -175,4 +175,35 @@ on_cherry_pick_button_clicked (GtkAction *action, Git *plugin)
 	anjuta_dock_replace_command_pane (ANJUTA_DOCK (plugin->dock), "CherryPick", 
 	                                  _("Cherry Pick"), NULL, pane, GDL_DOCK_BOTTOM, NULL, 
 	                                  0, NULL);
-}
\ No newline at end of file
+}
+
+void
+on_git_log_cherry_pick_activated (GtkAction *action, Git *plugin)
+{
+	GitRevision *revision;
+	gchar *sha;
+	GitCherryPickCommand *cherry_pick_command;
+
+	revision = git_log_pane_get_selected_revision (GIT_LOG_PANE (plugin->log_pane));
+
+	if (revision)
+	{
+		sha = git_revision_get_sha (revision);
+		cherry_pick_command = git_cherry_pick_command_new (plugin->project_root_directory,
+		                                                   sha, FALSE, FALSE, 
+		                                                   FALSE);
+
+		g_signal_connect (G_OBJECT (cherry_pick_command), "command-finished",
+		                  G_CALLBACK (git_pane_report_errors),
+		                  plugin);
+
+		g_signal_connect (G_OBJECT (cherry_pick_command), "command-finished",
+		                  G_CALLBACK (g_object_unref),
+		                  NULL);
+
+		anjuta_command_start (ANJUTA_COMMAND (cherry_pick_command));
+
+		g_free (sha);
+		g_object_unref (revision);
+	}
+}
