@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.7.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2012 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,13 +26,13 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_MKP_YY_MK_PARSER_H_INCLUDED
-# define YY_MKP_YY_MK_PARSER_H_INCLUDED
-/* Enabling traces.  */
+#ifndef YY_MKP_YY_PLUGINS_MK_PROJECT_MK_PARSER_H_INCLUDED
+# define YY_MKP_YY_PLUGINS_MK_PROJECT_MK_PARSER_H_INCLUDED
+/* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 1
 #endif
@@ -40,47 +40,46 @@
 extern int mkp_yydebug;
 #endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     EOL = 258,
-     SPACE = 259,
-     TAB = 260,
-     HASH = 261,
-     MACRO = 262,
-     VARIABLE = 263,
-     COMMA = 264,
-     COLON = 265,
-     DOUBLE_COLON = 266,
-     ORDER = 267,
-     SEMI_COLON = 268,
-     EQUAL = 269,
-     IMMEDIATE_EQUAL = 270,
-     CONDITIONAL_EQUAL = 271,
-     APPEND = 272,
-     CHARACTER = 273,
-     NAME = 274,
-     MK_VARIABLE = 275,
-     _PHONY = 276,
-     _SUFFIXES = 277,
-     _DEFAULT = 278,
-     _PRECIOUS = 279,
-     _INTERMEDIATE = 280,
-     _SECONDARY = 281,
-     _SECONDEXPANSION = 282,
-     _DELETE_ON_ERROR = 283,
-     _IGNORE = 284,
-     _LOW_RESOLUTION_TIME = 285,
-     _SILENT = 286,
-     _EXPORT_ALL_VARIABLES = 287,
-     _NOTPARALLEL = 288,
-     IFEQ = 289,
-     ELSE = 290,
-     ENDIF = 291
-   };
+  enum yytokentype
+  {
+    EOL = 258,
+    SPACE = 259,
+    TAB = 260,
+    HASH = 261,
+    MACRO = 262,
+    VARIABLE = 263,
+    COMMA = 264,
+    COLON = 265,
+    DOUBLE_COLON = 266,
+    ORDER = 267,
+    SEMI_COLON = 268,
+    EQUAL = 269,
+    IMMEDIATE_EQUAL = 270,
+    CONDITIONAL_EQUAL = 271,
+    APPEND = 272,
+    CHARACTER = 273,
+    NAME = 274,
+    MK_VARIABLE = 275,
+    _PHONY = 276,
+    _SUFFIXES = 277,
+    _DEFAULT = 278,
+    _PRECIOUS = 279,
+    _INTERMEDIATE = 280,
+    _SECONDARY = 281,
+    _SECONDEXPANSION = 282,
+    _DELETE_ON_ERROR = 283,
+    _IGNORE = 284,
+    _LOW_RESOLUTION_TIME = 285,
+    _SILENT = 286,
+    _EXPORT_ALL_VARIABLES = 287,
+    _NOTPARALLEL = 288,
+    IFEQ = 289,
+    ELSE = 290,
+    ENDIF = 291
+  };
 #endif
 /* Tokens.  */
 #define EOL 258
@@ -118,29 +117,29 @@ extern int mkp_yydebug;
 #define ELSE 290
 #define ENDIF 291
 
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef int YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+/* Location type.  */
 #if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
-typedef struct YYLTYPE
+typedef struct YYLTYPE YYLTYPE;
+struct YYLTYPE
 {
   int first_line;
   int first_column;
   int last_line;
   int last_column;
-} YYLTYPE;
-# define yyltype YYLTYPE /* obsolescent; will be withdrawn */
+};
 # define YYLTYPE_IS_DECLARED 1
 # define YYLTYPE_IS_TRIVIAL 1
 #endif
 
 
+
 #ifndef YYPUSH_MORE_DEFINED
 # define YYPUSH_MORE_DEFINED
 enum { YYPUSH_MORE = 4 };
@@ -148,21 +147,9 @@ enum { YYPUSH_MORE = 4 };
 
 typedef struct mkp_yypstate mkp_yypstate;
 
-#if defined __STDC__ || defined __cplusplus
 int mkp_yypush_parse (mkp_yypstate *ps, int pushed_char, YYSTYPE const *pushed_val, YYLTYPE *pushed_loc, void* scanner);
-#else
-int mkp_yypush_parse ();
-#endif
 
-#if defined __STDC__ || defined __cplusplus
 mkp_yypstate * mkp_yypstate_new (void);
-#else
-mkp_yypstate * mkp_yypstate_new ();
-#endif
-#if defined __STDC__ || defined __cplusplus
 void mkp_yypstate_delete (mkp_yypstate *ps);
-#else
-void mkp_yypstate_delete ();
-#endif
 
-#endif /* !YY_MKP_YY_MK_PARSER_H_INCLUDED  */
+#endif /* !YY_MKP_YY_PLUGINS_MK_PROJECT_MK_PARSER_H_INCLUDED  */
