@@ -142,6 +142,8 @@ strv_to_rgbav (const gchar **specs, gsize *size, GdkRGBA **colors)
 static void
 terminal_set_preferences (VteTerminal *term, GSettings* settings, TerminalPlugin *term_plugin)
 {
+	GSettingsSchemaSource *source;
+	GSettingsSchema *schema;
 	gchar *uuid;
 	gchar *path;
 	GSettings *profiles_list;
@@ -159,7 +161,17 @@ terminal_set_preferences (VteTerminal *term, GSettings* settings, TerminalPlugin
 
 	g_return_if_fail (settings != NULL);
 
-	profiles_list = g_settings_new (TERMINAL_PROFILES_LIST_SCHEMA);
+	/* Always autohide mouse */
+	vte_terminal_set_mouse_autohide (term, TRUE);
+
+	/* Check that terminal schemas really exist. They could be missing if gnome
+	 * terminal is not installed or there is an old version */
+	source = g_settings_schema_source_get_default ();
+	schema = g_settings_schema_source_lookup (source, TERMINAL_PROFILES_LIST_SCHEMA, TRUE);
+	if (schema == NULL) return;
+
+	profiles_list = g_settings_new_full (schema, NULL, NULL);
+	g_settings_schema_unref (schema);
 
 	/* Get selected profile */
 	bool_val = g_settings_get_boolean (settings, PREFS_TERMINAL_PROFILE_USE_DEFAULT);
@@ -172,9 +184,6 @@ terminal_set_preferences (VteTerminal *term, GSettings* settings, TerminalPlugin
 	g_free (uuid);
 	g_free (path);
 
-	/* Always autohide mouse */
-	vte_terminal_set_mouse_autohide (term, TRUE);
-
 	/* Set terminal font */
 	bool_val = g_settings_get_boolean (profile_settings, TERMINAL_PROFILE_USE_SYSTEM_FONT_KEY);
 	if (bool_val)
@@ -187,7 +196,17 @@ terminal_set_preferences (VteTerminal *term, GSettings* settings, TerminalPlugin
 		str_val = g_settings_get_string (profile_settings, TERMINAL_PROFILE_FONT_KEY);
 	}
 	if (str_val != NULL)
+	{
+#ifdef HAVE_VTE_2_90
 		vte_terminal_set_font_from_string (term, str_val);
+#else
+		PangoFontDescription *font_desc;
+
+		font_desc = pango_font_description_from_string (str_val);
+		vte_terminal_set_font (term, font_desc);
+		pango_font_description_free (font_desc);
+#endif
+	}
 
 	/* Set cursor blink */
 	str_val = g_settings_get_string (profile_settings, TERMINAL_PROFILE_CURSOR_BLINK_MODE_KEY);
@@ -215,11 +234,13 @@ terminal_set_preferences (VteTerminal *term, GSettings* settings, TerminalPlugin
 	bool_val = g_settings_get_boolean (profile_settings, TERMINAL_PROFILE_SCROLL_ON_OUTPUT_KEY);
 	vte_terminal_set_scroll_on_output (term, bool_val);
 
+#ifdef HAVE_VTE_2_90
 	/* Set word characters */
 	str_val = g_settings_get_string (profile_settings, TERMINAL_PROFILE_WORD_CHARS_KEY);
 	if (str_val != NULL)
 		vte_terminal_set_word_chars (term, str_val);
 	g_free (str_val);
+#endif
 
 	/* Set backspace key */
 	str_val = g_settings_get_string (profile_settings, TERMINAL_PROFILE_BACKSPACE_BINDING_KEY);
@@ -265,14 +286,18 @@ terminal_set_preferences (VteTerminal *term, GSettings* settings, TerminalPlugin
 	g_free (str_val);
 
 	str_vals = g_settings_get_strv(profile_settings, TERMINAL_PROFILE_PALETTE_KEY);
-	strv_to_rgbav (str_vals, &size, &palette);
+	strv_to_rgbav ((const gchar **) str_vals, &size, &palette);
 	g_free (str_vals);
 
 	/* vte_terminal_set_colors() works even if the terminal widget is not realized,
 	 * which is not the case with vte_terminal_set_color_foreground() and
 	 * vte_terminal_set_color_background()
 	 */
+#ifdef HAVE_VTE_2_90
 	vte_terminal_set_colors_rgba (term, foreground, background, palette, size);
+#else
+	vte_terminal_set_colors (term, foreground, background, palette, size);
+#endif
 
 	g_free (palette);
 	g_object_unref (profiles_list);
@@ -323,12 +348,18 @@ use_default_profile_cb (GtkToggleButton *button,
 		gtk_widget_set_sensitive (term->pref_profile_combo, TRUE);
 }
 
+#ifdef HAVE_VTE_2_90
 static void
 terminal_child_exited_cb (VteTerminal *term, gpointer user_data)
 {
+	int status = vte_terminal_get_child_exit_status (term);
+#else
+static void
+terminal_child_exited_cb (VteTerminal *term, int status, gpointer user_data)
+{
+#endif
 	TerminalPlugin *term_plugin = ANJUTA_PLUGIN_TERMINAL (user_data);
 	GPid pid = term_plugin->child_pid;
-	int status;
 	
 	if (term_plugin->child_pid)
 	{
@@ -344,7 +375,6 @@ terminal_child_exited_cb (VteTerminal *term, gpointer user_data)
 		term_plugin->child_pid = 0;
 	}
 
-	status = vte_terminal_get_child_exit_status (term);
 	g_signal_emit_by_name(term_plugin, "child-exited", pid, status);
 }
 
@@ -384,10 +414,17 @@ terminal_execute (TerminalPlugin *term_plugin, const gchar *directory,
 	vte_terminal_reset (term, TRUE, TRUE);
 */
 
+#ifdef HAVE_VTE_2_90
 	if (vte_terminal_fork_command_full (term, term_plugin->pty_flags,
 	                                    dir, args, environment,
 	                                    G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD, NULL, NULL,
 	                                    &pid, NULL))
+#else
+	if (vte_terminal_spawn_sync (term, term_plugin->pty_flags,
+								 dir, args, environment,
+								 G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD, NULL, NULL,
+								 &pid, NULL, NULL))
+#endif
 	{
 		gboolean focus;
 
@@ -429,10 +466,17 @@ init_shell (TerminalPlugin *term_plugin, const char *path)
 	else
 		first_time = FALSE;
 
+#ifdef HAVE_VTE_2_90
 	vte_terminal_fork_command_full (term, term_plugin->pty_flags,
 	                                path, shell, NULL,
 	                                0, NULL, NULL,
 	                                NULL, NULL);
+#else
+	vte_terminal_spawn_sync (term, term_plugin->pty_flags,
+							 path, shell, NULL,
+							 0, NULL, NULL,
+							 NULL, NULL, NULL);
+#endif
 	g_free (shell[0]);
 }
 
@@ -679,7 +723,11 @@ create_box (GtkWidget *term)
 {
 	GtkWidget *sb, *hbox;
 
+#ifdef HAVE_VTE_2_90
 	sb = gtk_scrollbar_new (GTK_ORIENTATION_VERTICAL, GTK_ADJUSTMENT (vte_terminal_get_adjustment (VTE_TERMINAL (term))));
+#else
+	sb = gtk_scrollbar_new (GTK_ORIENTATION_VERTICAL, gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (term)));
+#endif
 	gtk_widget_set_can_focus (sb, FALSE);
 
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
@@ -907,21 +955,6 @@ add_data_to_store (gchar *uuid, gchar *name, GtkListStore *model)
 	gtk_list_store_set (model, &iter, TERM_STORE_UUID_COLUMN, uuid, TERM_STORE_NAME_COLUMN, name, -1);
 }
 
-static void
-profile_renderer (GtkTreeViewColumn *column, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
-{
-	gchar *uuid;
-	gchar *name;
-	gchar *label;
-
-	gtk_tree_model_get (model, iter, TERM_STORE_UUID_COLUMN, &uuid, TERM_STORE_NAME_COLUMN, &name, -1);
-	label = g_strdup_printf ("%s (%s)", name, uuid);
-	g_object_set (renderer, "text", label, NULL);
-	g_free (uuid);
-	g_free (name);
-	g_free (label);
-}
-
 static void
 on_pref_profile_changed (GtkComboBox* combo, TerminalPlugin* term_plugin)
 {
@@ -938,11 +971,13 @@ on_pref_profile_changed (GtkComboBox* combo, TerminalPlugin* term_plugin)
 static void
 ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError** e)
 {
+	GSettingsSchemaSource *source;
+	GSettingsSchema *schema;
 	GSettings *terminal_settings;
 	GSettings *profile_settings;
 	GtkListStore *store;
 	GtkTreeIter iter;
-	gchar *default_uuid;
+	gchar *default_uuid = NULL;
 	gchar *saved_uuid;
 	gchar *temp;
 	gchar **profiles;
@@ -983,13 +1018,20 @@ ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError**
 	g_object_set (uuid_renderer, "style", PANGO_STYLE_ITALIC, NULL);
 
 	/* If at least a default profile exists ... */
-	terminal_settings = g_settings_new (TERMINAL_PROFILES_LIST_SCHEMA);
-	store = GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (term_plugin->pref_profile_combo)));
-	default_uuid = g_settings_get_string (terminal_settings, "default");
+	source = g_settings_schema_source_get_default ();
+	schema = g_settings_schema_source_lookup (source, TERMINAL_PROFILES_LIST_SCHEMA, TRUE);
+	if (schema != NULL)
+	{
+		terminal_settings = g_settings_new_full (schema, NULL, NULL);
+		default_uuid = g_settings_get_string (terminal_settings, "default");
+		g_settings_schema_unref (schema);
+	}
+
 	if (default_uuid != NULL) {
 
 		/* Populate profiles store */
 		profiles = g_settings_get_strv (terminal_settings, "list");
+		store = GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (term_plugin->pref_profile_combo)));
 		gtk_list_store_clear (store);
 		for (i = 0; profiles[i] != NULL; i ++) {
 			path = g_strdup_printf ("%s:%s/", TERMINAL_PROFILES_PATH_PREFIX, profiles[i]);
